Enumerations
============

.. module:: acmeow.enums

Type-safe enumerations used throughout the library.

ChallengeType
-------------

.. autoclass:: acmeow.ChallengeType
   :members:
   :undoc-members:
   :show-inheritance:

IdentifierType
--------------

.. autoclass:: acmeow.IdentifierType
   :members:
   :undoc-members:
   :show-inheritance:

KeyType
-------

.. autoclass:: acmeow.KeyType
   :members:
   :undoc-members:
   :show-inheritance:

OrderStatus
-----------

.. autoclass:: acmeow.OrderStatus
   :members:
   :undoc-members:
   :show-inheritance:

AuthorizationStatus
-------------------

.. autoclass:: acmeow.AuthorizationStatus
   :members:
   :undoc-members:
   :show-inheritance:

ChallengeStatus
---------------

.. autoclass:: acmeow.ChallengeStatus
   :members:
   :undoc-members:
   :show-inheritance:

AccountStatus
-------------

.. autoclass:: acmeow.AccountStatus
   :members:
   :undoc-members:
   :show-inheritance:

RevocationReason
----------------

.. autoclass:: acmeow.RevocationReason
   :members:
   :undoc-members:
   :show-inheritance:
